# PySoMQ: Python bindings for serial over ØMQ

This package utilizes the Python bindings of [ØMQ](http://www.zeromq.org) 
in order to provide a lightweight and fast serial bidirectional 
[PySerial](https://pypi.org/project/pyserial/) communication interface.

## Downloading

Unless you specifically want to develop PySoMQ, I recommend downloading
the PySoMQ source code or wheels from
[PyPI](https://pypi.io/project/pysomq).


## Development

You can get the latest source code from my 
[Gitlab](https://gitlab.com/casabre/pysomq)
 repository. For extension or bugfixes, please create a new branch with
  final merge request. Any contribution is appreciated!